@@ -132,7 +132,7 @@ pub enum RData {
     /// +----------------+----------------+.....+----------------+
     /// | Value byte 0   | Value byte 1   |.....| Value byte m-1 |
     /// +----------------+----------------+.....+----------------+
-
+    ///
     /// Where n is the length specified in the Tag length field and m is the
     /// remaining octets in the Value field (m = d - n - 2) where d is the
     /// length of the RDATA section.
@@ -1115,11 +1115,11 @@ mod tests {
                 RData::SOA(SOA::new(
                     Name::from_str("www.example.com").unwrap(),
                     Name::from_str("xxx.example.com").unwrap(),
-                    u32::max_value(),
+                    u32::MAX,
                     -1,
                     -1,
                     -1,
-                    u32::max_value(),
+                    u32::MAX,
                 )),
                 vec![
                     3, b'w', b'w', b'w', 7, b'e', b'x', b'a', b'm', b'p', b'l', b'e', 3, b'c',
@@ -1182,11 +1182,11 @@ mod tests {
             RData::SOA(SOA::new(
                 Name::from_str("www.example.com").unwrap(),
                 Name::from_str("xxx.example.com").unwrap(),
-                u32::max_value(),
+                u32::MAX,
                 -1,
                 -1,
                 -1,
-                u32::max_value(),
+                u32::MAX,
             )),
             RData::TXT(TXT::new(vec![
                 "abcdef".to_string(),
@@ -1203,11 +1203,11 @@ mod tests {
             RData::SOA(SOA::new(
                 Name::from_str("www.example.com").unwrap(),
                 Name::from_str("xxx.example.com").unwrap(),
-                u32::max_value(),
+                u32::MAX,
                 -1,
                 -1,
                 -1,
-                u32::max_value(),
+                u32::MAX,
             )),
             RData::TXT(TXT::new(vec![
                 "abcdef".to_string(),
