@@ -176,6 +176,12 @@ impl RecordType {
         )
     }
 
+    /// Returns true if this is an RRSIG RecordType
+    #[inline]
+    pub fn is_rrsig(self) -> bool {
+        self == Self::RRSIG
+    }
+
     /// Returns true if this is a Zero (unspecified) RecordType
     #[inline]
     pub fn is_zero(self) -> bool {
@@ -297,7 +303,7 @@ impl BinEncodable for RecordType {
     }
 }
 
-impl<'r> BinDecodable<'r> for RecordType {
+impl BinDecodable<'_> for RecordType {
     fn read(decoder: &mut BinDecoder<'_>) -> ProtoResult<Self> {
         Ok(decoder
             .read_u16()
